@@ -20,7 +20,7 @@
  * XSECAlgorithmHandlerDefault := Interface class to define handling of
  *								  default encryption algorithms
  *
- * $Id: DSIGAlgorithmHandlerDefault.cpp 575854 2007-09-15 02:08:41Z scantor $
+ * $Id: DSIGAlgorithmHandlerDefault.cpp 794017 2009-07-14 19:03:52Z scantor $
  *
  */
 
@@ -459,6 +459,12 @@ unsigned int DSIGAlgorithmHandlerDefault::signToSafeBuffer(
 		}
 
 		// Signature already created, so just translate to base 64 and enter string
+
+        // FIX: CVE-2009-0217
+        if (outputLength > 0 && (outputLength < 80 || outputLength < hashLen / 2)) {
+            throw XSECException(XSECException::AlgorithmMapperError,
+                "HMACOutputLength set to unsafe value.");
+        }
 		
 		convertRawToBase64String(b64SB, 
 								hash, 
@@ -560,7 +566,14 @@ bool DSIGAlgorithmHandlerDefault::verifyBase64Signature(
 	case (XSECCryptoKey::KEY_HMAC) :
 
 		// Already done - just compare calculated value with read value
-		sigVfyRet = compareBase64StringToRaw(sig, 
+
+        // FIX: CVE-2009-0217
+        if (outputLength > 0 && (outputLength < 80 || outputLength < hashLen / 2)) {
+            throw XSECException(XSECException::AlgorithmMapperError,
+                "HMACOutputLength set to unsafe value.");
+        }
+
+	    sigVfyRet = compareBase64StringToRaw(sig,
 			hash, 
 			hashLen,
 			outputLength);
