@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: DSIGConstants.cpp 450744 2006-09-28 07:52:02Z blautenb $
+ * $Id: DSIGConstants.cpp 783064 2009-06-09 16:58:25Z scantor $
  *
  */
 
@@ -167,6 +167,8 @@ const XMLCh * DSIGConstants::s_unicodeStrURIXSLT;
 const XMLCh * DSIGConstants::s_unicodeStrURIENVELOPE;
 const XMLCh * DSIGConstants::s_unicodeStrURIC14N_NOC;
 const XMLCh * DSIGConstants::s_unicodeStrURIC14N_COM;
+const XMLCh * DSIGConstants::s_unicodeStrURIC14N11_NOC;
+const XMLCh * DSIGConstants::s_unicodeStrURIC14N11_COM;
 const XMLCh * DSIGConstants::s_unicodeStrURIEXC_C14N_NOC;
 const XMLCh * DSIGConstants::s_unicodeStrURIEXC_C14N_COM;
 const XMLCh * DSIGConstants::s_unicodeStrURIDSA_SHA1;
@@ -241,6 +243,8 @@ void DSIGConstants::create() {
 	s_unicodeStrURIENVELOPE = XMLString::transcode(URI_ID_ENVELOPE);
 	s_unicodeStrURIC14N_NOC = XMLString::transcode(URI_ID_C14N_NOC);
 	s_unicodeStrURIC14N_COM = XMLString::transcode(URI_ID_C14N_COM);
+    s_unicodeStrURIC14N11_NOC = XMLString::transcode(URI_ID_C14N11_NOC);
+    s_unicodeStrURIC14N11_COM = XMLString::transcode(URI_ID_C14N11_COM);
 	s_unicodeStrURIEXC_C14N_NOC = XMLString::transcode(URI_ID_EXC_C14N_NOC);
 	s_unicodeStrURIEXC_C14N_COM = XMLString::transcode(URI_ID_EXC_C14N_COM);
 	s_unicodeStrURIDSA_SHA1 = XMLString::transcode(URI_ID_DSA_SHA1);
@@ -258,7 +262,7 @@ void DSIGConstants::create() {
 	s_unicodeStrURIHMAC_SHA512 = XMLString::transcode(URI_ID_HMAC_SHA512);
 	s_unicodeStrURIXMLNS = XMLString::transcode(URI_ID_XMLNS);
 	s_unicodeStrURIMANIFEST = XMLString::transcode(URI_ID_MANIFEST);
-	
+
 	s_unicodeStrURI3DES_CBC	= XMLString::transcode(URI_ID_3DES_CBC);
 	s_unicodeStrURIAES128_CBC	= XMLString::transcode(URI_ID_AES128_CBC);
 	s_unicodeStrURIAES192_CBC	= XMLString::transcode(URI_ID_AES192_CBC);
@@ -298,7 +302,7 @@ void DSIGConstants::destroy() {
 
 	XSEC_RELEASE_XMLCH(s_unicodeStrURISIGBASE);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURISIGBASEMORE);
-	
+
 	XSEC_RELEASE_XMLCH(s_unicodeStrURISHA1);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURISHA224);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURISHA256);
@@ -311,6 +315,8 @@ void DSIGConstants::destroy() {
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIENVELOPE);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIC14N_NOC);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIC14N_COM);
+    XSEC_RELEASE_XMLCH(s_unicodeStrURIC14N11_NOC);
+    XSEC_RELEASE_XMLCH(s_unicodeStrURIC14N11_COM);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIEXC_C14N_NOC);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIEXC_C14N_COM);
 	XSEC_RELEASE_XMLCH(s_unicodeStrURIDSA_SHA1);
@@ -343,7 +349,7 @@ void DSIGConstants::destroy() {
 
 	XSEC_RELEASE_XMLCH(s_unicodeStrPROVOpenSSL);
 	XSEC_RELEASE_XMLCH(s_unicodeStrPROVWinCAPI);
-  XSEC_RELEASE_XMLCH(s_unicodeStrPROVNSS);
+	XSEC_RELEASE_XMLCH(s_unicodeStrPROVNSS);
 
 }
 
@@ -395,8 +401,8 @@ bool getHashMethod(const XMLCh * URI, hashMethod & hm) {
 
 }
 
-bool XSECmapURIToSignatureMethods(const XMLCh * URI, 
-								  signatureMethod & sm, 
+bool XSECmapURIToSignatureMethods(const XMLCh * URI,
+								  signatureMethod & sm,
 								  hashMethod & hm) {
 
 
@@ -430,9 +436,8 @@ bool XSECmapURIToSignatureMethods(const XMLCh * URI,
 	}
 
 	/* Check to see if we are one of the more exotic RSA signatures */
+	xsecsize_t cnt = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASEMORE);
 
-	unsigned int cnt = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASEMORE);
-	
 	if (XMLString::compareNString(URI, DSIGConstants::s_unicodeStrURISIGBASEMORE, cnt) == 0) {
 
 		// Have an "new" algorithm
@@ -440,7 +445,7 @@ bool XSECmapURIToSignatureMethods(const XMLCh * URI,
 
 			// Some kind of HMAC
 			sm = SIGNATURE_HMAC;
-		
+
 			// Determine a trailing hash method
 			if (URI[cnt+4] != chDash)
 				return false;
@@ -464,14 +469,14 @@ bool XSECmapURIToSignatureMethods(const XMLCh * URI,
 
 }
 
-bool XSECmapURIToHashMethod(const XMLCh * URI, 
+bool XSECmapURIToHashMethod(const XMLCh * URI,
 							hashMethod & hm) {
 
 
 	// Check this is a known prefix on the URI.
-	unsigned int blen = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASE);
-	unsigned int bmlen = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASEMORE);
-	unsigned int belen = XMLString::stringLen(DSIGConstants::s_unicodeStrURIXENC);
+	xsecsize_t blen = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASE);
+	xsecsize_t bmlen = XMLString::stringLen(DSIGConstants::s_unicodeStrURISIGBASEMORE);
+	xsecsize_t belen = XMLString::stringLen(DSIGConstants::s_unicodeStrURIXENC);
 	if (XMLString::compareNString(URI, DSIGConstants::s_unicodeStrURISIGBASE, blen) == 0) {
 
 		// This is actually cheating - this will return SHA256 (as an example), even if
@@ -497,7 +502,7 @@ bool XSECmapURIToHashMethod(const XMLCh * URI,
 
 }
 
-bool XSECmapURIToCanonicalizationMethod(const XMLCh * URI, 
+bool XSECmapURIToCanonicalizationMethod(const XMLCh * URI,
 							canonicalizationMethod & cm) {
 
 	// Quick and dirty but inefficient
@@ -515,6 +520,12 @@ bool XSECmapURIToCanonicalizationMethod(const XMLCh * URI,
 	else if (strEquals(URI, DSIGConstants::s_unicodeStrURIEXC_C14N_NOC)) {
 		cm = CANON_C14NE_NOC;
 	}
+	else if (strEquals(URI, DSIGConstants::s_unicodeStrURIC14N11_NOC)) {
+        cm = CANON_C14N11_NOC;
+    }
+    else if (strEquals(URI, DSIGConstants::s_unicodeStrURIC14N11_COM)) {
+        cm = CANON_C14N11_COM;
+    }
 
 	else {
 
