@@ -17,10 +17,9 @@
 /*
  * XSEC
  *
- * DSIGKeyInfoX509 := A "Super" key that defines a certificate with a sub-key that defines
- *                the signing key
+ * DSIGKeyInfoName := References a key by name.
  *
- * $Id: DSIGKeyInfoName.hpp 351364 2005-06-04 11:30:26Z blautenb $
+ * $Id: DSIGKeyInfoName.hpp 738757 2009-01-29 04:25:58Z scantor $
  *
  */
 
@@ -103,7 +102,7 @@ public:
 	 * @returns A pointer to the char buffer containing the key name
 	 */
 
-	virtual const XMLCh * getKeyName(void) {return mp_name;};
+	virtual const XMLCh * getKeyName(void) const {return mp_name;};
 
 	/**
 	 * \brief Get the decoded key name (for distinguished names)
@@ -120,7 +119,7 @@ public:
 
 	/**@name Create and set functions */
 	//@{
-	
+
 	/**
 	 * \brief Create a new KeyName element in the current document.
 	 *
@@ -151,12 +150,12 @@ public:
 
 	/** @name Information Functions */
 	//@{
-	
+
 	/**
 	 * \brief Return type of this KeyInfo element
 	 */
-	
-	virtual keyInfoType getKeyInfoType(void) {return DSIGKeyInfo::KEYINFO_NAME;}
+
+	virtual keyInfoType getKeyInfoType(void) const {return DSIGKeyInfo::KEYINFO_NAME;}
 
 	//@}
 
@@ -166,7 +165,7 @@ private:
 
 	const XMLCh			* mp_name;				// The Data stored in the XML file
 	XMLCh				* mp_decodedDName;		// When this is a DName that needs decoding
-	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode				
+	XERCES_CPP_NAMESPACE_QUALIFIER DOMNode
 						* mp_keyNameTextNode;	// Text node containing the name
 
 };
