@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: DSIGSignature.cpp 450746 2006-09-28 07:53:23Z blautenb $
+ * $Id: DSIGSignature.cpp 794017 2009-07-14 19:03:52Z scantor $
  *
  */
 
@@ -329,6 +329,12 @@ DSIGReferenceList * DSIGSignature::getReferenceList(void) {
 
 }
 
+const DSIGReferenceList * DSIGSignature::getReferenceList(void) const {
+
+	return mp_signedInfo->getReferenceList();
+
+}
+
 // --------------------------------------------------------------------------------
 //           Set and Get Resolvers
 // --------------------------------------------------------------------------------
@@ -340,7 +346,7 @@ void DSIGSignature::setURIResolver(XSECURIResolver * resolver) {
 
 }
 
-XSECURIResolver * DSIGSignature::getURIResolver(void) {
+XSECURIResolver * DSIGSignature::getURIResolver(void) const {
 
 	return mp_env->getURIResolver();
 
@@ -355,7 +361,7 @@ void DSIGSignature::setKeyInfoResolver(XSECKeyInfoResolver * resolver) {
 
 }
 
-XSECKeyInfoResolver * DSIGSignature::getKeyInfoResolver(void) {
+XSECKeyInfoResolver * DSIGSignature::getKeyInfoResolver(void) const {
 
 	return mp_KeyInfoResolver;
 
@@ -380,7 +386,7 @@ DSIGObject * DSIGSignature::appendObject(void) {
 
 }
 
-int DSIGSignature::getObjectLength(void) {
+int DSIGSignature::getObjectLength(void) const {
 
 	return (unsigned int) m_objects.size();
 
@@ -397,6 +403,17 @@ DSIGObject * DSIGSignature::getObjectItem(int i) {
 
 }
 
+const DSIGObject * DSIGSignature::getObjectItem(int i) const {
+
+	if ( i < 0 || i >= ((int) m_objects.size())) {
+		throw XSECException(XSECException::ObjectError,
+			"DSIGSignature::getObjectItem - index out of range");
+	}
+
+	return m_objects[i];
+
+}
+
 // --------------------------------------------------------------------------------
 //           Signature
 // --------------------------------------------------------------------------------
@@ -488,7 +505,7 @@ DSIGSignature::~DSIGSignature() {
 
 // Actions
 
-const XMLCh * DSIGSignature::getErrMsgs() {
+const XMLCh * DSIGSignature::getErrMsgs() const {
 
 	return m_errStr.rawXMLChBuffer();
 
@@ -505,7 +522,7 @@ void DSIGSignature::setPrettyPrint(bool flag) {
 }
 
 
-bool DSIGSignature::getPrettyPrint(void) {
+bool DSIGSignature::getPrettyPrint(void) const {
 
 	return mp_env->getPrettyPrintFlag();
 
@@ -535,20 +552,20 @@ void DSIGSignature::setXPFNSPrefix(const XMLCh * prefix) {
 
 // get
 
-const XMLCh * DSIGSignature::getDSIGNSPrefix() {
+const XMLCh * DSIGSignature::getDSIGNSPrefix() const {
 
 	return mp_env->getDSIGNSPrefix();
 
 }
 
 
-const XMLCh * DSIGSignature::getECNSPrefix() {
+const XMLCh * DSIGSignature::getECNSPrefix() const {
 
 	return mp_env->getECNSPrefix();
 
 }
 
-const XMLCh * DSIGSignature::getXPFNSPrefix() {
+const XMLCh * DSIGSignature::getXPFNSPrefix() const {
 
 	return mp_env->getXPFNSPrefix();
 
@@ -1025,6 +1042,13 @@ bool DSIGSignature::verifySignatureOnlyInternal(void) {
 
 	}
 
+	// FIX: CVE-2009-0217
+
+	if (mp_signedInfo->getHMACOutputLength() > 0 && mp_signedInfo->getHMACOutputLength() < 80) {
+	    throw XSECException(XSECException::SigVfyError,
+            "DSIGSignature::verify() - HMACOutputLength is unsafe");
+	}
+
 	// Try to find a key
 	if (mp_signingKey == NULL) {
 
@@ -1228,7 +1252,7 @@ void DSIGSignature::setIdByAttributeName(bool flag) {
 
 }
 
-bool DSIGSignature::getIdByAttributeName(void) {
+bool DSIGSignature::getIdByAttributeName(void) const {
 
 	return mp_env->getIdByAttributeName();
 
