@@ -19,7 +19,7 @@
  *
  * DSIGSignedInfo := Class for checking and setting up signed Info nodes in a DSIG signature
  *
- * $Id: DSIGSignedInfo.cpp 450747 2006-09-28 07:54:22Z blautenb $
+ * $Id: DSIGSignedInfo.cpp 793085 2009-07-10 19:30:57Z scantor $
  *
  */
 
@@ -323,7 +323,19 @@ void DSIGSignedInfo::load(void) {
 
 	}
 
-	else if (tmpSB.sbStrcmp(URI_ID_EXC_C14N_COM) == 0) {
+	else if (tmpSB.sbStrcmp(URI_ID_C14N11_NOC) == 0) {
+
+        m_canonicalizationMethod = CANON_C14N11_NOC;
+
+    }
+
+    else if (tmpSB.sbStrcmp(URI_ID_C14N11_COM) == 0) {
+
+        m_canonicalizationMethod = CANON_C14N11_COM;
+
+    }
+
+    else if (tmpSB.sbStrcmp(URI_ID_EXC_C14N_COM) == 0) {
 
 		m_canonicalizationMethod = CANON_C14NE_COM;
 
