@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoHashHMAC.hpp 409949 2006-05-28 11:49:50Z blautenb $
+ * $Id: OpenSSLCryptoHashHMAC.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -153,7 +153,7 @@ public :
 	 * @returns The hash type
 	 */
 
-	virtual HashType getHashType(void);
+	virtual HashType getHashType(void) const;
 
 	/**
 	 * \brief Get OpenSSL Hash Context
