@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyHMAC.cpp 351210 2005-02-03 13:13:08Z milan $
+ * $Id: OpenSSLCryptoKeyHMAC.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -46,14 +46,14 @@ void OpenSSLCryptoKeyHMAC::setKey(unsigned char * inBuf, unsigned int inLength)
 
 }
 
-unsigned int OpenSSLCryptoKeyHMAC::getKey(safeBuffer &outBuf) {
+unsigned int OpenSSLCryptoKeyHMAC::getKey(safeBuffer &outBuf) const {
 
 	outBuf = m_keyBuf;
 	return m_keyLen;
 
 }
 
-XSECCryptoKey * OpenSSLCryptoKeyHMAC::clone() {
+XSECCryptoKey * OpenSSLCryptoKeyHMAC::clone() const {
 
 	OpenSSLCryptoKeyHMAC * ret;
 
