@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyHMAC.hpp 351364 2005-06-04 11:30:26Z blautenb $
+ * $Id: OpenSSLCryptoKeyHMAC.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -64,19 +64,19 @@ public :
 	 * public key, private key or a key pair
 	 */
 
-	virtual XSECCryptoKey::KeyType getKeyType() {return KEY_HMAC;}
+	virtual XSECCryptoKey::KeyType getKeyType() const {return KEY_HMAC;}
 
 	/**
 	 * \brief Replicate key
 	 */
 
-	virtual XSECCryptoKey * clone();
+	virtual XSECCryptoKey * clone() const;
 
 	/**
 	 * \brief Return the OpenSSL string identifier
 	 */
 
-	virtual const XMLCh * getProviderName() {return DSIGConstants::s_unicodeStrPROVOpenSSL;}
+	virtual const XMLCh * getProviderName() const {return DSIGConstants::s_unicodeStrPROVOpenSSL;}
 	
 	//@}
 
@@ -115,7 +115,7 @@ public :
 	 * @returns number of bytes copied in
 	 */
 
-	virtual unsigned int getKey(safeBuffer &outBuf);
+	virtual unsigned int getKey(safeBuffer &outBuf) const;
 
 	//@}
 
