@@ -22,7 +22,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoSymmetricKey.hpp 409949 2006-05-28 11:49:50Z blautenb $
+ * $Id: OpenSSLCryptoSymmetricKey.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -86,7 +86,7 @@ public :
 	 * \brief Returns a string that identifies the crypto owner of this library.
 	 */
 
-	virtual const XMLCh * getProviderName();
+	virtual const XMLCh * getProviderName() const;
 
 	/**
 	 * \brief Clone the key
@@ -96,7 +96,7 @@ public :
 	 * duplicate keys.
 	 */
 
-	virtual XSECCryptoKey * clone();
+	virtual XSECCryptoKey * clone() const;
 
 	//@}
 
@@ -111,7 +111,7 @@ public :
 	 * particular key
 	 */
 
-	SymmetricKeyType getSymmetricKeyType(void);
+	SymmetricKeyType getSymmetricKeyType(void) const;
 
 	/**
 	 * \brief Set the key from the provided bytes
@@ -276,6 +276,12 @@ public :
 
 	EVP_CIPHER_CTX * getOpenSSLEVP_CIPHER_CTX(void) {return &m_ctx;}
 
+    /**
+	 * \brief Get OpenSSL cipher context structure
+	 */
+
+	const EVP_CIPHER_CTX * getOpenSSLEVP_CIPHER_CTX(void) const {return &m_ctx;}
+
 	//@}
 
 private:
