@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoHash.cpp 369191 2006-01-15 09:14:43Z blautenb $
+ * $Id: WinCAPICryptoHash.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -149,7 +149,7 @@ unsigned int WinCAPICryptoHash::finish(unsigned char * hash,
 
 // Get information
 
-XSECCryptoHash::HashType WinCAPICryptoHash::getHashType(void) {
+XSECCryptoHash::HashType WinCAPICryptoHash::getHashType(void) const {
 
 	return m_hashType;			// This could be any kind of hash
 
