@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoHash.hpp 369191 2006-01-15 09:14:43Z blautenb $
+ * $Id: WinCAPICryptoHash.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -146,7 +146,7 @@ public :
 	 * @returns The hash type
 	 */
 
-	virtual HashType getHashType(void);
+	virtual HashType getHashType(void) const;
 
 	//@}
 
