@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoKeyDSA.cpp 369748 2006-01-17 10:51:13Z blautenb $
+ * $Id: WinCAPICryptoKeyDSA.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -109,7 +109,7 @@ WinCAPICryptoKeyDSA::~WinCAPICryptoKeyDSA() {
 
 // Generic key functions
 
-XSECCryptoKey::KeyType WinCAPICryptoKeyDSA::getKeyType() {
+XSECCryptoKey::KeyType WinCAPICryptoKeyDSA::getKeyType() const {
 
 	// Find out what we have
 	if (m_key == NULL) {
@@ -507,7 +507,7 @@ unsigned int WinCAPICryptoKeyDSA::signBase64Signature(unsigned char * hashBuf,
 // --------------------------------------------------------------------------------
 
 
-XSECCryptoKey * WinCAPICryptoKeyDSA::clone() {
+XSECCryptoKey * WinCAPICryptoKeyDSA::clone() const {
 
 	WinCAPICryptoKeyDSA * ret;
 
