@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoKeyHMAC.cpp 369191 2006-01-15 09:14:43Z blautenb $
+ * $Id: WinCAPICryptoKeyHMAC.cpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -47,14 +47,14 @@ void WinCAPICryptoKeyHMAC::setKey(unsigned char * inBuf, unsigned int inLength)
 
 }
 
-unsigned int WinCAPICryptoKeyHMAC::getKey(safeBuffer &outBuf) {
+unsigned int WinCAPICryptoKeyHMAC::getKey(safeBuffer &outBuf) const {
 
 	outBuf = m_keyBuf;
 	return m_keyLen;
 
 }
 
-XSECCryptoKey * WinCAPICryptoKeyHMAC::clone() {
+XSECCryptoKey * WinCAPICryptoKeyHMAC::clone() const {
 
 	WinCAPICryptoKeyHMAC * ret;
 
@@ -102,13 +102,13 @@ void WinCAPICryptoKeyHMAC::setWinKey(HCRYPTKEY k) {
 
 }
 
-HCRYPTKEY WinCAPICryptoKeyHMAC::getWinKey(void) {
+HCRYPTKEY WinCAPICryptoKeyHMAC::getWinKey(void) const {
 
 	return m_k;
 
 }
 
-HCRYPTPROV WinCAPICryptoKeyHMAC::getWinKeyProv(void) {
+HCRYPTPROV WinCAPICryptoKeyHMAC::getWinKeyProv(void) const {
 
 	return m_p;
 
