@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: WinCAPICryptoX509.hpp 369191 2006-01-15 09:14:43Z blautenb $
+ * $Id: WinCAPICryptoX509.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -94,7 +94,7 @@ public :
 	 *
 	 */
 
-	virtual XSECCryptoKey::KeyType getPublicKeyType();
+	virtual XSECCryptoKey::KeyType getPublicKeyType() const;
 
 	/**
 	 * \brief Get a copy of the public key.
@@ -104,13 +104,13 @@ public :
 	 *
 	 */
 
-	virtual XSECCryptoKey * clonePublicKey();
+	virtual XSECCryptoKey * clonePublicKey() const;
 
 	/**
 	 * \brief Returns a string that identifies the crypto owner of this library.
 	 */
 
-	virtual const XMLCh * getProviderName();
+    virtual const XMLCh * getProviderName() const {return DSIGConstants::s_unicodeStrPROVWinCAPI;}
 
 	//@}
 
@@ -136,6 +136,14 @@ public :
 
 	virtual safeBuffer &getDEREncodingSB(void) {return m_DERX509;}
 
+    /**
+	 * \brief Get a Base64 DER encoded copy of the certificate
+	 *
+	 * @returns A safeBuffer containing the DER encoded certificate
+	 */
+
+	virtual const safeBuffer &getDEREncodingSB(void) const {return m_DERX509;}
+
 	//@}
 
 private:
