@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECCryptoUtils.cpp 450743 2006-09-28 07:51:31Z blautenb $
+ * $Id: XSECCryptoUtils.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -80,12 +80,12 @@ int SASLCleanXKMSPassPhrase(unsigned char * input, int inputLen, safeBuffer &out
 	inp[inputLen] = '\0';
 
 	uinput = XMLString::transcode((char *) inp);
-	unsigned int l = XMLString::stringLen(uinput);
+	xsecsize_t l = XMLString::stringLen(uinput);
 	uoutput = new XMLCh[l + 1];
 	ArrayJanitor<XMLCh> j_uinput(uinput);
 	ArrayJanitor<XMLCh> j_uoutput(uoutput);
 
-	unsigned int i, j;
+	xsecsize_t i, j;
 	j = 0;
 
 	XMLCh ch1;
