@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECCryptoX509.hpp 351207 2005-02-03 12:48:16Z milan $
+ * $Id: XSECCryptoX509.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -68,7 +68,7 @@ public :
 	 *
 	 */
 
-	virtual XSECCryptoKey::KeyType getPublicKeyType() = 0;
+	virtual XSECCryptoKey::KeyType getPublicKeyType() const = 0;
 
 	/**
 	 * \brief Get a copy of the public key.
@@ -78,13 +78,13 @@ public :
 	 *
 	 */
 
-	virtual XSECCryptoKey * clonePublicKey() = 0;
+	virtual XSECCryptoKey * clonePublicKey() const = 0;
 
 	/**
 	 * \brief Returns a string that identifies the crypto owner of this library.
 	 */
 
-	virtual const XMLCh * getProviderName() = 0;
+	virtual const XMLCh * getProviderName() const = 0;
 
 	//@}
 
@@ -122,6 +122,14 @@ public :
 
 	virtual safeBuffer &getDEREncodingSB(void) = 0;		// Get the DER string
 
+    /**
+	 * \brief Get a Base64 DER encoded copy of the certificate
+	 *
+	 * @returns A safeBuffer containing the DER encoded certificate
+	 */
+
+	virtual const safeBuffer &getDEREncodingSB(void) const = 0;		// Get the DER string
+
 	//@}
 
 };
