@@ -19,7 +19,7 @@
  *
  * checkSig := (Very ugly) tool to check a signature embedded in an XML file
  *
- * $Id: checksig.cpp 389736 2006-03-29 10:00:42Z blautenb $
+ * $Id: checksig.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -333,7 +333,7 @@ int evaluate(int argc, char ** argv) {
 	// Now parse out file
 
 	bool errorsOccured = false;
-	int errorCount = 0;
+	xsecsize_t errorCount = 0;
     try
     {
     	parser->parse(filename);
