@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: cipher.cpp 450286 2006-09-27 01:47:51Z blautenb $
+ * $Id: cipher.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -557,7 +557,7 @@ int evaluate(int argc, char ** argv) {
 
 		// Now parse out file
 
-		int errorCount = 0;
+		xsecsize_t errorCount = 0;
 		try
 		{
     		parser->parse(filename);
@@ -681,7 +681,7 @@ int evaluate(int argc, char ** argv) {
 				Janitor<XSECBinTXFMInputStream> j_bis(bis);
 	
 				XMLByte buf[1024];			
-				unsigned int read = bis->readBytes(buf, 1023);
+				xsecsize_t read = bis->readBytes(buf, 1023);
 				while (read > 0) {
 					formatTarget->writeChars(buf, read, NULL);
 					read = bis->readBytes(buf, 1023);
