@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: siginf.cpp 389736 2006-03-29 10:00:42Z blautenb $
+ * $Id: siginf.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -204,8 +204,8 @@ void outputTransform(DSIGTransform * t, int level) {
 
 			if (atts != 0) {
 
-				unsigned int s = atts->getLength();
-				for (unsigned int i = 0 ; i < s; ++i) {
+				XMLSize_t s = atts->getLength();
+				for (XMLSize_t i = 0 ; i < s; ++i) {
 					levelSet(level);
 					cout << "Namespace : " << X2C(atts->item(i)->getNodeName()).str() <<
 						"=\"" << X2C(atts->item(i)->getNodeValue()).str() << "\"\n";
@@ -452,7 +452,7 @@ int evaluate(int argc, char ** argv) {
 	// Now parse out file
 
 	bool errorsOccured = false;
-	int errorCount = 0;
+	xsecsize_t errorCount = 0;
     try
     {
     	parser->parse(filename);
