@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: TXFMC14n.cpp 351391 2005-07-17 01:14:48Z blautenb $
+ * $Id: TXFMC14n.cpp 783064 2009-06-09 16:58:25Z scantor $
  *
  */
 
@@ -109,7 +109,7 @@ void TXFMC14n::setInput(TXFMBase *newInput) {
 	mp_c14n->setUseNamespaceStack(!input->nameSpacesExpanded());
 
 }
-	
+
 void TXFMC14n::activateComments(void) {
 
 	if (input != NULL)
@@ -136,6 +136,13 @@ void TXFMC14n::setExclusive(safeBuffer & NSList) {
 
 }
 
+void TXFMC14n::setInclusive11() {
+
+    if (mp_c14n != NULL)
+        mp_c14n->setInclusive11();
+
+}
+
 // Methods to get tranform output type and input requirement
 
 TXFMBase::ioType TXFMC14n::getInputType(void) {
@@ -164,7 +171,7 @@ unsigned int TXFMC14n::readBytes(XMLByte * const toFill, unsigned int maxToFill)
 
 		return 0;
 
-	return mp_c14n->outputBuffer(toFill, maxToFill);
+	return (unsigned int) mp_c14n->outputBuffer(toFill, maxToFill);
 
 }
 
