@@ -21,7 +21,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: TXFMParser.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: TXFMParser.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -114,10 +114,8 @@ void TXFMParser::setInput(TXFMBase *newInput) {
 	parser.setCreateEntityReferenceNodes(true);
 	parser.setDoSchema(true);
 
-	int errorCount = 0;
-
 	parser.parse(is);
-    errorCount = parser.getErrorCount();
+    xsecsize_t errorCount = parser.getErrorCount();
     if (errorCount > 0)
 		throw XSECException(XSECException::XSLError, "Errors occured parsing BYTE STREAM");
 
