@@ -19,7 +19,7 @@
  *
  * TXFMSB := Class that takes an input safeBuffer to start a transform pipe
  *
- * $Id: TXFMSB.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: TXFMSB.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -114,7 +114,7 @@ unsigned int TXFMSB::readBytes(XMLByte * const toFill, unsigned int maxToFill) {
 	if (toOutput <= maxToFill) {
 
 		memcpy((char *) toFill, &(sb.rawBuffer()[sbs - toOutput]), toOutput);
-		ret = toOutput;
+		ret = (unsigned int) toOutput;
 		toOutput = 0;
 
 		return ret;
