@@ -19,7 +19,7 @@
  *
  * TXFMURL := Class that takes an input URL to start of a transform pipe
  *
- * $Id: TXFMURL.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: TXFMURL.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -122,7 +122,7 @@ unsigned int TXFMURL::readBytes(XMLByte * const toFill, unsigned int maxToFill)
 	if (done || is == NULL) return 0;
 
 	try {
-		ret = is->readBytes(toFill, maxToFill);
+		ret = (unsigned int) is->readBytes(toFill, maxToFill);
 	}
 	catch (NetAccessorException e) {
 
