@@ -19,15 +19,15 @@
  *
  * XSECTXFMInputSource := Transfomer InputSource for Xerces Parser.
  *
- * $Id: XSECTXFMInputSource.cpp 351214 2005-02-03 13:58:14Z milan $
+ * $Id: XSECTXFMInputSource.cpp 575863 2007-09-15 03:11:33Z scantor $
  *
  *					 
  */
 
 
-#include "XSECTXFMInputSource.hpp"
 #include <xsec/transformers/TXFMBase.hpp>
 #include <xsec/utils/XSECBinTXFMInputStream.hpp>
+#include <xsec/utils/XSECTXFMInputSource.hpp>
 #include <xsec/framework/XSECError.hpp>
 
 #include <xercesc/util/BinInputStream.hpp>
