@@ -19,7 +19,7 @@
  *
  * XENCCipherImpl := Implementation of the main encryption worker class
  *
- * $Id: XENCCipherImpl.cpp 464121 2006-10-15 05:15:59Z blautenb $
+ * $Id: XENCCipherImpl.cpp 724055 2008-12-06 23:34:24Z scantor $
  *
  */
 
@@ -329,15 +329,12 @@ DOMDocumentFragment * XENCCipherImpl::deSerialise(safeBuffer &content, DOMNode *
 
 	// Create an input source
 
-	unsigned int bytes = XMLString::stringLen(sbt.rawCharBuffer());
+	xsecsize_t bytes = XMLString::stringLen(sbt.rawCharBuffer());
 	MemBufInputSource* memIS = new MemBufInputSource ((const XMLByte*) sbt.rawBuffer(), bytes, "XSECMem");
 	Janitor<MemBufInputSource> j_memIS(memIS);
 
-	int errorCount = 0;
-
-
 	parser->parse(*memIS);
-    errorCount = parser->getErrorCount();
+    xsecsize_t errorCount = parser->getErrorCount();
     if (errorCount > 0)
         throw XSECException(XSECException::CipherError, "Errors occured during de-serialisation of decrypted element content");
 
