@@ -19,7 +19,7 @@
  *
  * XENCEncryptedKeyImpl := Implementation for holder object for EncryptedKey 
  *
- * $Id: XENCEncryptedKeyImpl.hpp 351314 2005-05-09 14:32:35Z milan $
+ * $Id: XENCEncryptedKeyImpl.hpp 566299 2007-08-15 18:51:47Z scantor $
  *
  */
 
@@ -57,8 +57,8 @@ public:
 								 const XMLCh * value);
 
 	// KeyInfo Interface methods
-	virtual const XMLCh * getKeyName(void) {return NULL;}
-	virtual keyInfoType getKeyInfoType(void) {return DSIGKeyInfo::KEYINFO_ENCRYPTEDKEY;}
+	virtual const XMLCh * getKeyName(void) const {return NULL;}
+	virtual keyInfoType getKeyInfoType(void) const {return DSIGKeyInfo::KEYINFO_ENCRYPTEDKEY;}
 
 
 	// Inherited from XENCEncryptedData - need to re-implement
