@@ -19,7 +19,7 @@
  *
  * XKMSConstants := Definitions of varius XKMSconstants (mainly strings)
  *
- * $Id: XKMSConstants.cpp,v 1.17 2005/02/03 14:15:49 milan Exp $
+ * $Id: XKMSConstants.cpp 383302 2006-03-05 10:20:07Z blautenb $
  *
  */
 
@@ -123,6 +123,26 @@ const XMLCh XKMSConstants::s_tagCompoundResult[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagD[] = {
+
+	chLatin_D,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagDP[] = {
+
+	chLatin_D,
+	chLatin_P,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagDQ[] = {
+
+	chLatin_D,
+	chLatin_Q,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagEncryption[] = {
 
 	chLatin_E,
@@ -151,6 +171,19 @@ const XMLCh XKMSConstants::s_tagExchange[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagExponent[] = {
+
+	chLatin_E,
+	chLatin_x,
+	chLatin_p,
+	chLatin_o,
+	chLatin_n,
+	chLatin_e,
+	chLatin_n,
+	chLatin_t,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagFailure[] = {
 
 	chLatin_F,
@@ -203,6 +236,19 @@ const XMLCh XKMSConstants::s_tagInvalidReason[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagInverseQ[] = {
+
+	chLatin_I,
+	chLatin_n,
+	chLatin_v,
+	chLatin_e,
+	chLatin_r,
+	chLatin_s,
+	chLatin_e,
+	chLatin_Q,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagIndeterminateReason[] = {
 
 	chLatin_I,
@@ -377,6 +423,18 @@ const XMLCh XKMSConstants::s_tagMessageExtension[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagModulus[] = {
+
+	chLatin_M,
+	chLatin_o,
+	chLatin_d,
+	chLatin_u,
+	chLatin_l,
+	chLatin_u,
+	chLatin_s,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagNonce[] = {
 
 	chLatin_N,
@@ -503,6 +561,12 @@ const XMLCh XKMSConstants::s_tagOriginalRequestId[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagP[] = {
+
+	chLatin_P,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagPending[] = {
 
 	chLatin_P,
@@ -534,6 +598,21 @@ const XMLCh XKMSConstants::s_tagPendingRequest[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagPrivateKey[] = {
+
+	chLatin_P,
+	chLatin_r,
+	chLatin_i,
+	chLatin_v,
+	chLatin_a,
+	chLatin_t,
+	chLatin_e,
+	chLatin_K,
+	chLatin_e,
+	chLatin_y,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagProofOfPossession[] = {
 
 	chLatin_P,
@@ -593,6 +672,12 @@ const XMLCh XKMSConstants::s_tagPrototypeKeyBinding[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagQ[] = {
+
+	chLatin_Q,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagQueryKeyBinding[] = {
 
 	chLatin_Q,
@@ -613,6 +698,65 @@ const XMLCh XKMSConstants::s_tagQueryKeyBinding[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagRecoverKeyBinding[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_c,
+	chLatin_o,
+	chLatin_v,
+	chLatin_e,
+	chLatin_r,
+	chLatin_K,
+	chLatin_e,
+	chLatin_y,
+	chLatin_B,
+	chLatin_i,
+	chLatin_n,
+	chLatin_d,
+	chLatin_i,
+	chLatin_n,
+	chLatin_g,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagRecoverRequest[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_c,
+	chLatin_o,
+	chLatin_v,
+	chLatin_e,
+	chLatin_r,
+	chLatin_R,
+	chLatin_e,
+	chLatin_q,
+	chLatin_u,
+	chLatin_e,
+	chLatin_s,
+	chLatin_t,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagRecoverResult[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_c,
+	chLatin_o,
+	chLatin_v,
+	chLatin_e,
+	chLatin_r,
+	chLatin_R,
+	chLatin_e,
+	chLatin_s,
+	chLatin_u,
+	chLatin_l,
+	chLatin_t,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagRegisterRequest[] = {
 
 	chLatin_R,
@@ -652,6 +796,65 @@ const XMLCh XKMSConstants::s_tagRegisterResult[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagReissueKeyBinding[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_i,
+	chLatin_s,
+	chLatin_s,
+	chLatin_u,
+	chLatin_e,
+	chLatin_K,
+	chLatin_e,
+	chLatin_y,
+	chLatin_B,
+	chLatin_i,
+	chLatin_n,
+	chLatin_d,
+	chLatin_i,
+	chLatin_n,
+	chLatin_g,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagReissueRequest[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_i,
+	chLatin_s,
+	chLatin_s,
+	chLatin_u,
+	chLatin_e,
+	chLatin_R,
+	chLatin_e,
+	chLatin_q,
+	chLatin_u,
+	chLatin_e,
+	chLatin_s,
+	chLatin_t,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagReissueResult[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_i,
+	chLatin_s,
+	chLatin_s,
+	chLatin_u,
+	chLatin_e,
+	chLatin_R,
+	chLatin_e,
+	chLatin_s,
+	chLatin_u,
+	chLatin_l,
+	chLatin_t,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagRepresent[] = {
 
 	chLatin_R,
@@ -820,6 +1023,25 @@ const XMLCh XKMSConstants::s_tagResultMinor[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagRevocationCode[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_v,
+	chLatin_o,
+	chLatin_c,
+	chLatin_a,
+	chLatin_t,
+	chLatin_i,
+	chLatin_o,
+	chLatin_n,
+	chLatin_C,
+	chLatin_o,
+	chLatin_d,
+	chLatin_e,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagRevocationCodeIdentifier[] = {
 
 	chLatin_R,
@@ -849,6 +1071,77 @@ const XMLCh XKMSConstants::s_tagRevocationCodeIdentifier[] = {
 	chNull
 };
 
+const XMLCh XKMSConstants::s_tagRevokeKeyBinding[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_v,
+	chLatin_o,
+	chLatin_k,
+	chLatin_e,
+	chLatin_K,
+	chLatin_e,
+	chLatin_y,
+	chLatin_B,
+	chLatin_i,
+	chLatin_n,
+	chLatin_d,
+	chLatin_i,
+	chLatin_n,
+	chLatin_g,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagRevokeRequest[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_v,
+	chLatin_o,
+	chLatin_k,
+	chLatin_e,
+	chLatin_R,
+	chLatin_e,
+	chLatin_q,
+	chLatin_u,
+	chLatin_e,
+	chLatin_s,
+	chLatin_t,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagRevokeResult[] = {
+
+	chLatin_R,
+	chLatin_e,
+	chLatin_v,
+	chLatin_o,
+	chLatin_k,
+	chLatin_e,
+	chLatin_R,
+	chLatin_e,
+	chLatin_s,
+	chLatin_u,
+	chLatin_l,
+	chLatin_t,
+	chNull
+};
+
+const XMLCh XKMSConstants::s_tagRSAKeyPair[] = {
+
+	chLatin_R,
+	chLatin_S,
+	chLatin_A,
+	chLatin_K,
+	chLatin_e,
+	chLatin_y,
+	chLatin_P,
+	chLatin_a,
+	chLatin_i,
+	chLatin_r,
+	chNull
+};
+
 const XMLCh XKMSConstants::s_tagService[] = {
 
 	chLatin_S,
