@@ -19,7 +19,7 @@
  *
  * XKMSMessageFactoryImpl := Implementation of the XKMSMessageFactory class
  *
- * $Id: XKMSMessageFactoryImpl.cpp,v 1.18 2005/02/26 03:17:08 blautenb Exp $
+ * $Id: XKMSMessageFactoryImpl.cpp 383302 2006-03-05 10:20:07Z blautenb $
  *
  */
 
@@ -45,6 +45,12 @@
 #include "XKMSPendingRequestImpl.hpp"
 #include "XKMSRegisterRequestImpl.hpp"
 #include "XKMSRegisterResultImpl.hpp"
+#include "XKMSRevokeResultImpl.hpp"
+#include "XKMSRevokeRequestImpl.hpp"
+#include "XKMSRecoverResultImpl.hpp"
+#include "XKMSRecoverRequestImpl.hpp"
+#include "XKMSReissueResultImpl.hpp"
+#include "XKMSReissueRequestImpl.hpp"
 
 XERCES_CPP_NAMESPACE_USE
 
@@ -314,6 +320,89 @@ XKMSMessageAbstractType * XKMSMessageFactoryImpl::newMessageFromDOM(
 		j_ret.release();
 		return (XKMSRegisterResult *) ret;
 
+	}
+	else if (strEquals(name, XKMSConstants::s_tagRevokeRequest)) {
+
+		// This is a <RevokeRequest> message
+		XKMSRevokeRequestImpl * ret;
+		XSECnew(ret, XKMSRevokeRequestImpl(env, elt));
+		Janitor<XKMSRevokeRequestImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSRevokeRequest *) ret;
+
+	}
+
+	else if (strEquals(name, XKMSConstants::s_tagRevokeResult)) {
+
+		// This is a <RevokeResult> message
+		XKMSRevokeResultImpl * ret;
+		XSECnew(ret, XKMSRevokeResultImpl(env, elt));
+		Janitor<XKMSRevokeResultImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSRevokeResult *) ret;
+
+	}
+
+	else if (strEquals(name, XKMSConstants::s_tagRecoverRequest)) {
+
+		// This is a <RevokeRequest> message
+		XKMSRecoverRequestImpl * ret;
+		XSECnew(ret, XKMSRecoverRequestImpl(env, elt));
+		Janitor<XKMSRecoverRequestImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSRecoverRequest *) ret;
+
+	}
+
+	else if (strEquals(name, XKMSConstants::s_tagRecoverResult)) {
+
+		// This is a <RecoverResult> message
+		XKMSRecoverResultImpl * ret;
+		XSECnew(ret, XKMSRecoverResultImpl(env, elt));
+		Janitor<XKMSRecoverResultImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSRecoverResult *) ret;
+
+	}
+
+	else if (strEquals(name, XKMSConstants::s_tagReissueRequest)) {
+
+		// This is a <ReissueRequest> message
+		XKMSReissueRequestImpl * ret;
+		XSECnew(ret, XKMSReissueRequestImpl(env, elt));
+		Janitor<XKMSReissueRequestImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSReissueRequest *) ret;
+
+	}
+
+	else if (strEquals(name, XKMSConstants::s_tagReissueResult)) {
+
+		// This is a <RevokeResult> message
+		XKMSReissueResultImpl * ret;
+		XSECnew(ret, XKMSReissueResultImpl(env, elt));
+		Janitor<XKMSReissueResultImpl> j_ret(ret);
+
+		ret->load();
+		
+		j_ret.release();
+		return (XKMSReissueResult *) ret;
+
 	}
 
 	delete env;
@@ -562,6 +651,126 @@ XKMSRegisterRequest * XKMSMessageFactoryImpl::createRegisterRequest(
 	return rri;
 }
 
+XKMSRevokeRequest * XKMSMessageFactoryImpl::createRevokeRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id) {
+	
+	XKMSRevokeRequestImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSRevokeRequestImpl(tenv));
+	rri->createBlankRevokeRequest(service, id);
+
+	return rri;
+
+}
+
+
+XKMSRevokeRequest * XKMSMessageFactoryImpl::createRevokeRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id) {
+
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSRevokeRequest * rri = createRevokeRequest(service, *doc, id);
+	(*doc)->appendChild(rri->getElement());
+
+	return rri;
+}
+
+XKMSRecoverRequest * XKMSMessageFactoryImpl::createRecoverRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id) {
+	
+	XKMSRecoverRequestImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSRecoverRequestImpl(tenv));
+	rri->createBlankRecoverRequest(service, id);
+
+	return rri;
+
+}
+
+
+XKMSRecoverRequest * XKMSMessageFactoryImpl::createRecoverRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id) {
+
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSRecoverRequest * rri = createRecoverRequest(service, *doc, id);
+	(*doc)->appendChild(rri->getElement());
+
+	return rri;
+}
+
+XKMSReissueRequest * XKMSMessageFactoryImpl::createReissueRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc,
+		const XMLCh * id) {
+	
+	XKMSReissueRequestImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSReissueRequestImpl(tenv));
+	rri->createBlankReissueRequest(service, id);
+
+	return rri;
+
+}
+
+
+XKMSReissueRequest * XKMSMessageFactoryImpl::createReissueRequest(
+		const XMLCh * service,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		const XMLCh * id) {
+
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSReissueRequest * rri = createReissueRequest(service, *doc, id);
+	(*doc)->appendChild(rri->getElement());
+
+	return rri;
+}
+
 // --------------------------------------------------------------------------------
 //           Create a result based on a request
 // --------------------------------------------------------------------------------
@@ -831,6 +1040,139 @@ XKMSRegisterResult * XKMSMessageFactoryImpl::createRegisterResult(
 }
 
 
+XKMSRevokeResult * XKMSMessageFactoryImpl::createRevokeResult(
+		XKMSRevokeRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	XKMSRevokeResultImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSRevokeResultImpl(tenv));
+	rri->createBlankRevokeResult(request->getService(), id, rmaj, rmin);
+
+	copyRequestToResult(request, (XKMSResultTypeImpl*) rri);
+
+	return rri; 
+
+}
+
+
+XKMSRevokeResult * XKMSMessageFactoryImpl::createRevokeResult(
+		XKMSRevokeRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSRevokeResult * rr = createRevokeResult(request, *doc, rmaj, rmin, id);
+	(*doc)->appendChild(rr->getElement());
+
+	return rr;
+}
+
+XKMSReissueResult * XKMSMessageFactoryImpl::createReissueResult(
+		XKMSReissueRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	XKMSReissueResultImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSReissueResultImpl(tenv));
+	rri->createBlankReissueResult(request->getService(), id, rmaj, rmin);
+
+	copyRequestToResult(request, (XKMSResultTypeImpl*) rri);
+
+	return rri; 
+
+}
+
+XKMSReissueResult * XKMSMessageFactoryImpl::createReissueResult(
+		XKMSReissueRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSReissueResult * rr = createReissueResult(request, *doc, rmaj, rmin, id);
+	(*doc)->appendChild(rr->getElement());
+
+	return rr;
+}
+
+XKMSRecoverResult * XKMSMessageFactoryImpl::createRecoverResult(
+		XKMSRecoverRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument *doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	XKMSRecoverResultImpl * rri;
+
+	XSECEnv * tenv;
+	XSECnew(tenv, XSECEnv(*mp_env));
+	tenv->setParentDocument(doc);
+
+	XSECnew(rri, XKMSRecoverResultImpl(tenv));
+	rri->createBlankRecoverResult(request->getService(), id, rmaj, rmin);
+
+	copyRequestToResult(request, (XKMSResultTypeImpl*) rri);
+
+	return rri; 
+
+}
+
+XKMSRecoverResult * XKMSMessageFactoryImpl::createRecoverResult(
+		XKMSRecoverRequest * request,
+		XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument **doc,
+		XKMSResultType::ResultMajor rmaj,
+		XKMSResultType::ResultMinor rmin,
+		const XMLCh * id) {
+
+	// Create a document to put the element in
+
+	XMLCh tempStr[100];
+	XMLString::transcode("Core", tempStr, 99);    
+	DOMImplementation *impl = DOMImplementationRegistry::getDOMImplementation(tempStr);
+
+	*doc = impl->createDocument();
+
+	// Embed the new structure in the document
+	XKMSRecoverResult * rr = createRecoverResult(request, *doc, rmaj, rmin, id);
+	(*doc)->appendChild(rr->getElement());
+
+	return rr;
+}
+
 // --------------------------------------------------------------------------------
 //           Message Conversions
 // --------------------------------------------------------------------------------
@@ -846,6 +1188,9 @@ XKMSRequestAbstractType * XKMSMessageFactoryImpl::toRequestAbstractType(XKMSMess
 	case XKMSMessageAbstractType::CompoundRequest :
 	case XKMSMessageAbstractType::PendingRequest :
 	case XKMSMessageAbstractType::RegisterRequest :
+	case XKMSMessageAbstractType::RevokeRequest :
+	case XKMSMessageAbstractType::RecoverRequest :
+	case XKMSMessageAbstractType::ReissueRequest :
 	case XKMSMessageAbstractType::StatusRequest :
 
 		return (XKMSRequestAbstractType *) msg;
@@ -867,6 +1212,9 @@ XKMSResultType * XKMSMessageFactoryImpl::toResultType(XKMSMessageAbstractType *m
 	case XKMSMessageAbstractType::ValidateResult :
 	case XKMSMessageAbstractType::CompoundResult :
 	case XKMSMessageAbstractType::RegisterResult :
+	case XKMSMessageAbstractType::RevokeResult :
+	case XKMSMessageAbstractType::RecoverResult :
+	case XKMSMessageAbstractType::ReissueResult :
 	case XKMSMessageAbstractType::StatusResult :
 	case XKMSMessageAbstractType::Result :
 
